@@ -3,6 +3,7 @@
  * Debian run-parts program
  * Copyright (C) 1996 Jeff Noxon <jeff@router.patch.net>,
  * Copyright (C) 1996-1999 Guy Maor <maor@debian.org>
+ * Copyright (C) 2002, 2003, 2004, 2005 Clint Adams <schizo@debian.org>
  *
  * This is free software; see the GNU General Public License version 2
  * or later for copying conditions.  There is NO warranty.
@@ -20,7 +21,9 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <fcntl.h>
+#ifdef HAVE_GETOPT_H
 #include <getopt.h>
+#endif /* HAVE_GETOPT_H */
 #include <string.h>
 #include <errno.h>
 #include <ctype.h>
@@ -59,7 +62,7 @@ void version()
   fprintf(stderr, "Debian run-parts program, version " PACKAGE_VERSION
 	  "\nCopyright (C) 1994 Ian Jackson, Copyright (C) 1996 Jeff Noxon.\n"
 	  "Copyright (C) 1996,1997,1998,1999 Guy Maor\n"
-	  "Copyright (C) 2002, 2003, 2004 Clint Adams\n"
+	  "Copyright (C) 2002, 2003, 2004, 2005 Clint Adams\n"
 	  "This is free software; see the GNU General Public License version 2\n"
 	  "or later for copying conditions.  There is NO warranty.\n");
   exit(0);
@@ -379,14 +382,14 @@ void run_parts(char *dirname)
       }
       else if (S_ISLNK(st.st_mode)) {
 	if (!list_mode) {
-	  printf("run-parts: component %s is a broken symbolic link\n",filename);
+	  error("run-parts: component %s is a broken symbolic link\n",filename);
 	  exitstatus = 1;
 	}
       }
     }
     else if (!S_ISDIR(st.st_mode)) {
       if (!list_mode) {
-	printf("run-parts: component %s is not an executable plain file\n",
+	error("run-parts: component %s is not an executable plain file\n",
 	       filename);
 	exitstatus = 1;
       }
@@ -453,13 +456,13 @@ int main(int argc, char *argv[])
   /* We require exactly one argument: the directory name */
   if (optind != (argc - 1)) {
     error("missing operand");
-    fprintf(stderr, "Try run-parts --help' for more information.\n");
+    fprintf(stderr, "Try `run-parts --help' for more information.\n");
     exit(1);
   }
 
   if (list_mode && test_mode) {
     error("--list and --test can not be used together");
-    fprintf(stderr, "Try run-parts --help' for more information.\n");
+    fprintf(stderr, "Try `run-parts --help' for more information.\n");
     exit(1);
   }
 
